@@ -176,12 +176,12 @@ class BaseLog:
             "tcode": self.t_code if dialog_type == 'in' else f_code,
             "method_code": method_code,
             "http_method": http_method,
-            "request_time": request_time.strftime("%Y-%m-%d %H:%M:%S"),
+            "request_time": request_time.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3],
             "request_headers": request_headers,
             "request_payload": request_content,
             "response_headers": response_headers,
             "response_payload": response_content,
-            "response_time": response_time.strftime("%Y-%m-%d %H:%M:%S"),
+            "response_time": response_time.strftime("%Y-%m-%d %H:%M:%S.%f"[:-3]),
             "response_code": response_code,
             "response_remark": remark,
             "http_status_code": http_status_code,
