@@ -124,8 +124,8 @@ class MainLog(BaseLog):
                         response_time = datetime.datetime.now()
                         com_name = request.headers.environ['HTTP_HOST']  # + ":" + request.environ['']#主机名
                         message = {u'actionCode': action_code,
-                                   u'requestTime': request_time.strftime("%Y-%m-%d %H:%M:%S"),
-                                   u'responseTime': response_time.strftime("%Y-%m-%d %H:%M:%S"),
+                                   u'requestTime': request_time.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3],
+                                   u'responseTime': response_time.strftime("%Y-%m-%d %H:%M:%S")[:-3],
                                    u'requestContent': request_content,
                                    u'responseContent': response_content,
                                    u'requesturl': request_url,
